diff --git a/COPYING b/COPYING
index a0afa77..d72cee1 100644
--- a/COPYING
+++ b/COPYING
@@ -1,5 +1,5 @@
-Copyright (c) 2014-2016 Delta Consultants
-Copyright (c) 2014-2016 GoUrl.io Developers
+Copyright (c) 2014-2016 Delta Consultants
+Copyright (c) 2014-2016 GoUrl.io Developers
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
diff --git a/Examples/pay-per-product-multi.php b/Examples/pay-per-product-multi.php
index b0329ca..397bdf0 100644
--- a/Examples/pay-per-product-multi.php
+++ b/Examples/pay-per-product-multi.php
@@ -176,7 +176,7 @@ function cryptobox_new_payment($paymentID = 0, $payment_details = array(), $box_
is_paid()) echo $coins_list . "
Pay Invoice Now -
"; ?>
Language:
-display_cryptobox(true, 570, 230, "border-radius:15px;border:1px solid #eee;padding:3px 6px;margin:10px;", "display:inline-block;max-width:580px;padding:15px 20px;border:1px solid #eee;margin:7px;line-height:25px;"); ?>
+display_cryptobox(true, 580, 230, "border-radius:15px;border:1px solid #eee;padding:3px 6px;margin:10px;", "display:inline-block;max-width:580px;padding:15px 20px;border:1px solid #eee;margin:7px;line-height:25px;"); ?>
Message :
diff --git a/Examples/pay-per-product.php b/Examples/pay-per-product.php
index 0966c6d..d16faf1 100644
--- a/Examples/pay-per-product.php
+++ b/Examples/pay-per-product.php
@@ -136,7 +136,7 @@ function cryptobox_new_payment($paymentID = 0, $payment_details = array(), $box_
is_paid()) echo "Pay Invoice Now -
"; else echo "
"; ?>
Language:
-display_cryptobox(true, 570, 230); ?>
+display_cryptobox(true, 580, 230); ?>
Message :
diff --git a/cryptobox.callback.php b/cryptobox.callback.php
index 4a826ee..1e6344c 100644
--- a/cryptobox.callback.php
+++ b/cryptobox.callback.php
@@ -7,7 +7,7 @@
* @copyright 2014-2016 Delta Consultants
* @category Libraries
* @website https://gourl.io
- * @version 1.7.5
+ * @version 1.7.6
*
*
* This file processes call-backs from Cryptocoin Payment Box server when new payment
diff --git a/cryptobox.config.php b/cryptobox.config.php
index 4d3941f..05b91eb 100644
--- a/cryptobox.config.php
+++ b/cryptobox.config.php
@@ -1,6 +1,6 @@
\ No newline at end of file
diff --git a/cryptobox.js b/cryptobox.js
index 7375398..7a5224d 100644
--- a/cryptobox.js
+++ b/cryptobox.js
@@ -7,7 +7,7 @@
* @category Javascript
* @website https://gourl.io
* @api https://gourl.io/api.html
- * @version 1.7.5
+ * @version 1.7.6
*
*/
diff --git a/cryptobox.min.js b/cryptobox.min.js
index 015aefa..61097c2 100644
--- a/cryptobox.min.js
+++ b/cryptobox.min.js
@@ -7,7 +7,7 @@
* @category Javascript
* @website https://gourl.io
* @api https://gourl.io/api.html
- * @version 1.7.5
+ * @version 1.7.6
*
*/
diff --git a/index.html b/index.html
index 6c15c77..c1d48d8 100644
--- a/index.html
+++ b/index.html
@@ -1,8 +1,8 @@
403 Forbidden
-
-
+
+
Directory access is forbidden.
diff --git a/readme.md b/readme.md
index 4c330ac..4af64ad 100644
--- a/readme.md
+++ b/readme.md
@@ -2,7 +2,7 @@
GoUrl.io Cryptocoin Payment Gateway API
-----------------------------------------
-Version 1.7.5
+Version 1.7.6
**Accept Bitcoin, Litecoin, Paycoin, Dogecoin, Dash, Speedcoin, Reddcoin, Potcoin, Feathercoin, Vertcoin, Vericoin, Peercoin, MonetaryUnit Payments Online on your website**
@@ -25,7 +25,7 @@ Our Payment Gateway with Instant Checkout allows you to easily organise your web
* Direct Integration on your website (iframe), no external payment pages opens (as other payment gateways offer)
* User will see successful payment result typically within 5 seconds after the payment has been sent
* Your website users and visitors will see GoUrl payment box on your website in their own native languages
-* Our Payment Gateway supports the following interface languages: [English](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=en#gourlcryptolang), [Spanish](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=es#gourlcryptolang), [French](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=fr#gourlcryptolang), [German](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=de#gourlcryptolang), [Russian](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=ru#gourlcryptolang), [Dutch](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=nl#gourlcryptolang), [Persian](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=fa#gourlcryptolang), [Arabic](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=ar#gourlcryptolang), [Simplified Chinese](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=cn#gourlcryptolang), [Traditional Chinese](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=zh#gourlcryptolang), [Hindi](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=hi#gourlcryptolang). We can also add any new language to payment system on [request](https://gourl.io/api-php.html#lan)
+* Our Payment Gateway supports the following interface languages: [English](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=en#gourlcryptolang), [Spanish](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=es#gourlcryptolang), [French](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=fr#gourlcryptolang), [German](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=de#gourlcryptolang), [Russian](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=ru#gourlcryptolang), [Dutch](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=nl#gourlcryptolang), [Portuguese](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=pt#gourlcryptolang), [Persian](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=fa#gourlcryptolang), [Arabic](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=ar#gourlcryptolang), [Simplified Chinese](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=cn#gourlcryptolang), [Traditional Chinese](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=zh#gourlcryptolang), [Hindi](https://gourl.io/bitcoin-payment-gateway-api.html?gourlcryptolang=hi#gourlcryptolang). We can also add any new language to payment system on [request](https://gourl.io/api-php.html#lan)
* [Affiliate Program for Web Developers](https://gourl.io/affiliates.html) - Earn 0.50% Lifetime from each cryptocoin payment made by users through GoUrl Payment Gateway
* Global, Anonymous, Secure, Zero Risk, No Chargebacks, No visitor registration is needed.
* GoUrl Bitcoin Official [Wordpress Plugin](https://gourl.io/bitcoin-wordpress-plugin.html) - easy to use on your website
diff --git a/cryptobox.class.php b/cryptobox.class.php
index 40319f0..69d89d9 100644
--- a/cryptobox.class.php
+++ b/cryptobox.class.php
@@ -11,7 +11,7 @@
* @example https://gourl.io/bitcoin-payment-gateway-api.html
* @gitHub https://github.com/cryptoapi/Payment-Gateway
* @license Free GPLv2
- * @version 1.7.5
+ * @version 1.7.6
*
*
*
@@ -58,7 +58,7 @@
elseif (!defined('ABSPATH')) exit; // Wordpress
-define("CRYPTOBOX_VERSION", "1.7.5");
+define("CRYPTOBOX_VERSION", "1.7.6");
// GoUrl supported crypto currencies
define("CRYPTOBOX_COINS", json_encode(array('bitcoin', 'litecoin', 'paycoin', 'dogecoin', 'dash', 'speedcoin', 'reddcoin', 'potcoin', 'feathercoin', 'vertcoin', 'vericoin', 'peercoin', 'monetaryunit')));
@@ -79,7 +79,7 @@ class Cryptobox {
* User will pay you all times the actual price which is linked on current exchange price in USD on the datetime of purchase.
* You can use in cryptobox options one variable only: amount or amountUSD. You cannot place values of those two variables together. */
private $period = ""; // period after which the payment becomes obsolete and new cryptobox will be shown; allow values: NOEXPIRY, 1 MINUTE..90 MINUTE, 1 HOUR..90 HOURS, 1 DAY..90 DAYS, 1 WEEK..90 WEEKS, 1 MONTH..90 MONTHS
- private $language = "en"; // cryptobox localisation; en - English, es - Spanish, fr - French, de - German, ru - Russian, nl - Dutch, fa - Persian, ar - Arabic, cn - Simplified Chinese, zh - Traditional Chinese, hi - Hindi
+ private $language = "en"; // cryptobox localisation; en - English, es - Spanish, fr - French, de - German, ru - Russian, nl - Dutch, pt - Portuguese, fa - Persian, ar - Arabic, cn - Simplified Chinese, zh - Traditional Chinese, hi - Hindi
private $iframeID = ""; // optional, html iframe element id; allow symbols: a..Z0..9_-
private $orderID = ""; // your page name / product name or order name (not unique); allow symbols: a..Z0..9_-@.; max size: 50 symbols
private $userID = ""; // optional, manual setup unique identifier for each of your users; allow symbols: a..Z0..9_-@.; max size: 50 symbols
@@ -109,7 +109,7 @@ class Cryptobox {
private $boxType = ""; // cryptobox type - 'paymentbox' or 'captchabox'
private $processed = false; // optional - set flag to paid & processed
private $cookieName = ""; // user cookie/session name (if cookies/sessions use)
- private $localisation = ""; // localisation; en - English, es - Spanish, fr - French, de - German, ru - Russian, nl - Dutch, fa - Persian, ar - Arabic, cn - Simplified Chinese, zh - Traditional Chinese, hi - Hindi
+ private $localisation = ""; // localisation; en - English, es - Spanish, fr - French, de - German, ru - Russian, nl - Dutch, pt - Portuguese, fa - Persian, ar - Arabic, cn - Simplified Chinese, zh - Traditional Chinese, hi - Hindi
public function __construct($options = array())
@@ -643,6 +643,7 @@ private function check_payment_live()
curl_setopt( $ch, CURLOPT_POSTFIELDS, http_build_query($data));
curl_setopt( $ch, CURLOPT_HEADER, 0);
curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1);
+ curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, 20);
curl_setopt( $ch, CURLOPT_TIMEOUT, 20);
$res = curl_exec( $ch );
@@ -1038,13 +1039,12 @@ function convert_currency_live($from_Currency, $to_Currency, $amount)
$url = "https://www.google.com/finance/converter?a=".$amount."&from=".$from_Currency."&to=".$to_Currency;
$ch = curl_init();
- $timeout = 20;
curl_setopt ($ch, CURLOPT_URL, $url);
curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, FALSE);
curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
curl_setopt ($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0)");
- curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
- curl_setopt ($ch, CURLOPT_TIMEOUT, $timeout);
+ curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, 20);
+ curl_setopt ($ch, CURLOPT_TIMEOUT, 20);
$rawdata = curl_exec($ch);
curl_close($ch);
$data = explode('bld>', $rawdata);
@@ -1162,15 +1162,15 @@ function run_sql($sql)
}
// en - English, es - Spanish, fr - French, de - German, ru - Russian, nl - Dutch, fa - Persian, ar - Arabic, cn - Simplified Chinese, zh - Traditional Chinese, hi - Hindi
$cryptobox_localisation = array(
"en" => array("name" => "English",
- /*19*/ "button" => "Click Here if you have already sent %coinNames%",
- /*29*/ "msg_not_received" => "%coinNames% have not yet been received.
If you have already sent %coinNames% (the exact %coinName% sum in one payment as shown in the box below), please wait a few minutes to receive them by %coinName% Payment System. If you send any other sum, Payment System will ignore the transaction and you will need to send the correct sum again, or contact the site owner for assistance.",
- /*30*/ "msg_received" => "%coinName% Payment System received %amountPaid% %coinLabel% successfully !",
- /*31*/ "msg_received2" => "%coinName% Captcha received %amountPaid% %coinLabel% successfully !",
- /*95*/ "payment" => "Select Payment Method",
- /*96*/ "pay_in" => "Payment in %coinName%"),
+ /*36*/ "button" => "Click Here if you have already sent %coinNames%",
+ /*37*/ "msg_not_received" => "%coinNames% have not yet been received.
If you have already sent %coinNames% (the exact %coinName% sum in one payment as shown in the box below), please wait a few minutes to receive them by %coinName% Payment System. If you send any other sum, Payment System will ignore the transaction and you will need to send the correct sum again, or contact the site owner for assistance.",
+ /*38*/ "msg_received" => "%coinName% Payment System received %amountPaid% %coinLabel% successfully !",
+ /*39*/ "msg_received2" => "%coinName% Captcha received %amountPaid% %coinLabel% successfully !",
+ /*40*/ "payment" => "Select Payment Method",
+ /*42*/ "pay_in" => "Payment in %coinName%"),
"es" => array("name" => "Spanish",
"button" => "Click aqui si ya has mandado %coinNames%",
@@ -1211,7 +1211,15 @@ function run_sql($sql)
"msg_received2" => "%coinName% Captcha Systeem heeft %amountPaid% %coinLabel% succesvol ontvangen !",
"payment" => "Kies uw betaalmethode",
"pay_in" => "Betaling in %coinName%"),
-
+
+ "pt" => array("name" => "Portuguese",
+ "button" => "Se ja enviou %coinNames% clique aqui",
+ "msg_not_received" => "Os %coinNames% ainda não foram recebidos.
Se já enviou %coinNames% (a soma exata de %coinName% num só pagamento, como mostrado na caixa abaixo), por favor, espere alguns minutos para o sistema de pagamentos %coinName% os receber. Se enviar qualquer outro montante, o sistema de pagamentos irá ignorar a transação e terá que enviar a soma correta novamente; ou entre em contato com o proprietário do site para assistência.",
+ "msg_received" => "O sistema de pagamentos %coinName% recebeu %amountPaid% %coinLabel% com sucesso !",
+ "msg_received2" => "%coinName% Captcha recebeu %amountPaid% %coinLabel% com sucesso !",
+ "payment" => "Selecione o metodo de pagamento",
+ "pay_in" => "Pagamento em %coinName%"),
+
"fa" => array("name" => "Persian",
"button" => "اگر شما از قبل ارسال %coinName% اينجا را کليک کنيد",
"msg_not_received" => "%coinNames% هنوز دريافت نشده است
اگر شما قبلا ارسال کرديد %coinNames% ,به صورت دقيق %coinName% مجموع در يک پرداخت همانگونه که در کادر زير نشان داده شده است , لطفا چند دقيقه براي دريافت از طرف %coinName% پرداخت سيستم صبر کنيد. اگر شما هر گونه مجموع ديگري از پرداخت را فرستاده ايد, سيستم پرداخت معامله را ناديده مي گيرد و شما نياز به ارسال مجموع درستي که ذکر شد داريد, يا با دارنده سايت براي کمک و توضيحات بيشتر تماس بگيريد.",
@@ -1262,6 +1270,6 @@ function run_sql($sql)
foreach ($cryptobox_private_keys as $v)
if (strpos($v, " ") !== false || strpos($v, "PRV") === false || strpos($v, "AA") === false || strpos($v, "77") === false) die("Invalid Private Key - ". (CRYPTOBOX_WORDPRESS ? "please setup it on your plugin settings page" : "$v in variable \$cryptobox_private_keys, file cryptobox.config.php."));
- unset($v); unset($cryptobox_private_keys);
+ unset($v); unset($cryptobox_private_keys);
}
?>
\ No newline at end of file
@@ -1162,15 +1162,15 @@ function run_sql($sql)
}
- // en - English, es - Spanish, fr - French, de - German, ru - Russian, nl - Dutch, fa - Persian, ar - Arabic, cn - Simplified Chinese, zh - Traditional Chinese, hi - Hindi
+ // en - English, es - Spanish, fr - French, de - German, ru - Russian, nl - Dutch, pt - Portuguese, fa - Persian, ar - Arabic, cn - Simplified Chinese, zh - Traditional Chinese, hi - Hindi
$cryptobox_localisation = array(
"en" => array("name" => "English",